@@ -3,7 +3,7 @@ import hashlib
 import string
 import random
 import utils.objectUtils as objUtils
-import string_format as format 
+import utils.string_format as strFormat 
 
 def hash(value):
     '''
@@ -127,10 +127,10 @@ def variations(value,**kwargs):
         varis.extend(generate_typos(value))
     if case_variations is True:
 
-        varis.append(format.to_snake_case(value))
-        varis.append(format.to_screaming_snake(value))
-        varis.extend(format.title_case(varis))
-        varis.extend(format.title_case(varis,True))
+        varis.append(strFormat.to_snake_case(value))
+        varis.append(strFormat.to_screaming_snake(value))
+        varis.extend(strFormat.title_case(varis))
+        varis.extend(strFormat.title_case(varis,True))
     varis = list(set(varis))
     return varis
 
